pub struct GitLabERGlobalSettings {
pub domain: String,
pub project_path: String,
pub labels: Vec<String>,
pub url_char_limit: usize,
pub title_char_limit: usize,
pub description_char_limit: usize,
pub release_format_settings_stderr: ErrorFmtSettings,
}Expand description
Global configuration for GitLab issue submission.
Set once at application startup via
GlobalSettings::set_global_settings.
Fields
domain: StringGitLab domain (e.g. "gitlab.com" or "gitlab.example.com").
project_path: StringProject path (e.g. "my-group/my-project").
labels: Vec<String>Labels to apply to created issues.
url_char_limit: usizeLimit that will disable parts of the report in order to stay under this limit (if possible) Default: 2085
title_char_limit: usizeHard limit for title, title will be cut off on or before this limit. This limit takes into account character boundaries. Default: 1024
description_char_limit: usizeHard limit for description, description will be cut off on or before this limit. This limit takes into account character boundaries. Default: 1_048_576 (1MB)
release_format_settings_stderr: ErrorFmtSettingsFormatter for bug report printed to terminal in stderr This is the exact same message as is included in reporting link (before reducing because of char_limit).
Because it is printed to standard error it can contain color or be otherwise easier to read. These settings do not apply to output in debug builds or to the output in the link.
Default settings is same as format in Link